==> haskell-mockery-0.3.5-57-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-mockery.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mockery
version: 0.3.5
id: mockery-0.3.5-GUbAc4Lpo1SIB5Azgu2KDf
key: mockery-0.3.5-GUbAc4Lpo1SIB5Azgu2KDf
license: MIT
copyright: (c) 2015-2016 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
synopsis: Support functions for automated testing
description:
    Support functions for automated testing
category: Testing
abi: 7404543cfcecd5227fc205822582bc63
exposed: True
exposed-modules:
    Test.Mockery.Directory Test.Mockery.Environment
    Test.Mockery.Logging
hidden-modules: Paths_mockery
import-dirs: /usr/lib/ghc-8.6.5/site-local/mockery-0.3.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/mockery-0.3.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/mockery-0.3.5
hs-libraries: HSmockery-0.3.5-GUbAc4Lpo1SIB5Azgu2KDf
depends:
    base-4.12.0.0 base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    bytestring-0.10.8.2 directory-1.3.3.0 filepath-1.4.2.1
    logging-facade-0.3.0-4aOfazaWEnBFYj25lGMAFY
    temporary-1.3-DtA9I5S66596vhEnbtLJ0Y
haddock-interfaces: /usr/share/doc/haskell-mockery/html/mockery.haddock
haddock-html: /usr/share/doc/haskell-mockery/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mockery-0.3.5-58-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-mockery.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mockery
version: 0.3.5
id: mockery-0.3.5-CCSm3N4t6hJ9mue2yTjrv0
key: mockery-0.3.5-CCSm3N4t6hJ9mue2yTjrv0
license: MIT
copyright: (c) 2015-2016 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
synopsis: Support functions for automated testing
description:
    Support functions for automated testing
category: Testing
abi: 1cbe2d353566d9889379541641d6a4e4
exposed: True
exposed-modules:
    Test.Mockery.Directory Test.Mockery.Environment
    Test.Mockery.Logging
hidden-modules: Paths_mockery
import-dirs: /usr/lib/ghc-8.6.5/site-local/mockery-0.3.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/mockery-0.3.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/mockery-0.3.5
hs-libraries: HSmockery-0.3.5-CCSm3N4t6hJ9mue2yTjrv0
depends:
    base-4.12.0.0 base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    bytestring-0.10.8.2 directory-1.3.3.0 filepath-1.4.2.1
    logging-facade-0.3.0-GXlRa6C5dLL7yowOEeiilv
    temporary-1.3-LlCRdZN5kP3FxzYC5G3hZS
haddock-interfaces: /usr/share/doc/haskell-mockery/html/mockery.haddock
haddock-html: /usr/share/doc/haskell-mockery/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
